//
//  ExportOptionsViewController.js
//  Kite
//
//  Created by Joe Rhodes
//  Copyright (c) 2015 Joe Rhodes. All rights reserved.
//


@import 'UserDefaults.js'
@import 'ExportOptions.js'


ExportOptionsViewController = function() {

    this.view = this.buildView()
}

ExportOptionsViewController.prototype = {

    exportOptions: function() {

        var exportTextLayersAsImages = this.imageLayersOptionButton.state() == NSOnState ? true : false
        var exportShapeLayersAsImages = this.shapeImageLayersOptionButton.state() == NSOnState ? true : false
        var flattenLayersWithSuffix = this.flattenCheckbox.state() == NSOnState
        var imageExportScale = this.imageScalePopUpButton.titleOfSelectedItem() == "1x" ? 1 : 2

        // Save User defaults
        //
        UserDefaults.exportTextLayersAsImages = exportTextLayersAsImages
        UserDefaults.exportShapeLayersAsImages = exportShapeLayersAsImages
        UserDefaults.flattenLayersWithSuffix = flattenLayersWithSuffix

        var options = new ExportOptions({

            exportTextLayersAsImages: exportTextLayersAsImages,
            exportShapeLayersAsImages: exportShapeLayersAsImages,
            flattenLayersWithSuffix: flattenLayersWithSuffix,
            exportCurrentPageOnly: false,
            imageExportScale: imageExportScale,
        })

        return options
    },

    // -------------------------------------------------------------------------------------------
    // Helper
    // -------------------------------------------------------------------------------------------

    buildView: function() {

        var view = NSView.alloc().initWithFrame(NSMakeRect(0, 0, 502, 196))
        var flattenLabel = this.makeTextLabel("Layer flattening", NSMakeRect(47, 159, 99, 17))
        var flattenCheckbox = this.makeCheckboxButton("Flatten group layers with the \"**\" name suffix", NSMakeRect(150, 158, 297, 18))

        // TODO: Needed throughout the whole view. Add constraints.
        // view.heightAnchor().constraintEqualToConstant(196).setActive(true)

        // Text layer options
        //
        var textLayersLabel = this.makeTextLabel("Export text layers as", NSMakeRect(18, 130, 128, 17))
        var textOptionsWrapperView = NSView.alloc().initWithFrame( NSMakeRect(145, 101, 116, 52) )
        var textLayersOptionButton = this.makeOptionButton("Text Layers", NSMakeRect(6, 28, 92, 18))
        var imageLayersOptionButton = this.makeOptionButton("Image Layers", NSMakeRect(6, 6, 105, 18))

        // Shape layer options
        //
        var pathOptionsLabel = this.makeTextLabel("Export paths as", NSMakeRect(46, 78, 99, 17))
        var pathOptionsWrapperView = NSView.alloc().initWithFrame( NSMakeRect(145, 49, 116, 52) )
        var shapeLayersOptionButton = this.makeOptionButton("Shape Layers", NSMakeRect(6, 28, 104, 18))
        var shapeImageLayersOptionButton = this.makeOptionButton("Image Layers", NSMakeRect(6, 6, 105, 18))

        // Image Scale options
        //
        var imageScaleLabel = this.makeTextLabel("Export images at", NSMakeRect(39, 23, 107, 17))
        var imageScalePopUpButton = [[NSPopUpButton alloc] initWithFrame:NSMakeRect(150, 17, 64, 26) pullsDown:false]]
        var scaleLabel = this.makeTextLabel("scale", NSMakeRect(217, 23, 36, 17))

        imageScalePopUpButton.addItemWithTitle("1x")
        imageScalePopUpButton.addItemWithTitle("2x")

        view.addSubview(flattenLabel)
        view.addSubview(flattenCheckbox)

        view.addSubview(textLayersLabel)
        view.addSubview(textOptionsWrapperView)
        textOptionsWrapperView.addSubview(textLayersOptionButton)
        textOptionsWrapperView.addSubview(imageLayersOptionButton)

        view.addSubview(pathOptionsLabel)
        view.addSubview(pathOptionsWrapperView)
        pathOptionsWrapperView.addSubview(shapeLayersOptionButton)
        pathOptionsWrapperView.addSubview(shapeImageLayersOptionButton)

        view.addSubview(imageScaleLabel)
        view.addSubview(imageScalePopUpButton)
        view.addSubview(scaleLabel)

        this.flattenCheckbox = flattenCheckbox
        this.textLayersOptionButton = textLayersOptionButton
        this.imageLayersOptionButton = imageLayersOptionButton

        this.shapeLayersOptionButton = shapeLayersOptionButton
        this.shapeImageLayersOptionButton = shapeImageLayersOptionButton

        this.imageScalePopUpButton = imageScalePopUpButton

        this.setupSavedUserDefaults()

        return view
    },

    makeTextLabel: function(title, frame) {

        var label = NSTextField.alloc().initWithFrame(frame)
        label.drawsBackground = false
        label.editable = false
        label.selectable = false
        label.bordered = false

        label.attributedStringValue = this.makeAttributedStringWithRegularSize(title)
        label.sizeToFit()

        return label
    },

    makeOptionButton: function(title, frame) {

        var optionButton = NSButton.alloc().initWithFrame(frame)
        optionButton.setButtonType(NSRadioButton)
        optionButton.title = this.makeAttributedStringWithRegularSize(title)
        optionButton.controlSize = NSRegularControlSize
        optionButton.target = nil
        optionButton.action = "kiteExportOptionButtonClicked" // This won't actually get called
        optionButton.sizeToFit()

        return optionButton
    },

    makeCheckboxButton: function(title, frame) {

        var button = NSButton.alloc().initWithFrame(frame)
        button.setButtonType(NSSwitchButton)
        button.title = this.makeAttributedStringWithRegularSize(title)
        button.controlSize = NSRegularControlSize
        button.sizeToFit()

        return button
    },

    makeAttributedStringWithRegularSize: function(string) {

        var systemFontSize = NSFont.systemFontSize()
        var font = NSFont.systemFontOfSize(systemFontSize)

        return [NSAttributedString attributedStringWithString:string font:font]
    },

    setupSavedUserDefaults: function() {

        var exportTextLayersAsImages = UserDefaults.exportTextLayersAsImages
        var exportShapeLayersAsImages = UserDefaults.exportShapeLayersAsImages
        var flattenLayersWithSuffix = UserDefaults.flattenLayersWithSuffix
        var scaleFactor = NSScreen.mainScreen().backingScaleFactor()

        // Setup User Defaults
        //
        if (exportTextLayersAsImages) {
            this.imageLayersOptionButton.state = NSOnState
        }
        else {
            this.textLayersOptionButton.state = NSOnState
        }

        if (exportShapeLayersAsImages) {
            this.shapeImageLayersOptionButton.state = NSOnState
        }
        else {
            this.shapeLayersOptionButton.state = NSOnState
        }

        this.flattenCheckbox.state = flattenLayersWithSuffix ? NSOnState : NSOffState

        var titleToSelect = scaleFactor == 1 ? "1x" : "2x"
        this.imageScalePopUpButton.selectItemWithTitle(titleToSelect)
    },
}
