//
//  Exporter.js
//  Kite
//
//  Created by Joe Rhodes
//  Copyright (c) 2015 Joe Rhodes. All rights reserved.
//


@import 'KiteDocument.js'
@import 'Helpers.js'
@import 'ExportOptions.js'
@import 'ExportOptionsViewController.js'


Exporter = function(context) {

    this.sketchDoc = context.document
}

Exporter.prototype = {

    makeSavePanelWithDocumentName: function(documentName) {

        var savePanel = [NSSavePanel savePanel]
        savePanel.title = "Export to Kite"
        savePanel.nameFieldStringValue = documentName
        savePanel.allowedFileTypes = ["kite"]
        savePanel.accessoryView = this.exportOptionsView.view

        return savePanel
    },

    export: function() {

        var exportOptions = this.exportOptions()

        if (exportOptions != nil && Object.keys(exportOptions).length > 0)
        {
            var destinationURL = exportOptions.destinationURL
            var tempURL = this.tempURLWithFileName(destinationURL.lastPathComponent())

            log("temp URL: " + tempURL.path())
            log("Got Options: " + JSON.stringify(exportOptions))

            var exportInfo = {
                exportOptions: exportOptions,
                sketchDocument: this.sketchDoc,
            }

            var kiteDoc = new KiteDocument(tempURL, this.sketchDoc, exportInfo)
            var saveWasSuccessful = kiteDoc.save(exportInfo)

            if (saveWasSuccessful) {
                this.moveSavedDocumentAtTempURLToFinalURL(tempURL, destinationURL)
            }
        }
        else {
            var message = "Could not create export options"

            log(message)
            this.sketchDoc.showMessage(message)
        }
    },

    exportOptions: function() {

        var options = {}

        // If we have preconfigued the export options, use those, else
        // run a save panel to ask the user for the options
        //
        if ( Object.keys(ExportOptions.preconfiguredOptions).length > 0 ) {

            log("Using preconfigured Options")
            options = ExportOptions.preconfiguredOptions
        }
        else {
            log("Using Save Panel Options")
            options = this.exportOptionsWithSavePanel()
        }

        return options
    },

    exportOptionsWithSavePanel: function() {

        this.exportOptionsView = new ExportOptionsViewController()

        var options = {}
        var documentName = this.sketchDoc.displayName()
        var savePanel = this.makeSavePanelWithDocumentName(documentName)

        var choice = [savePanel runModal]
        var url = [savePanel URL]

        if (choice == NSFileHandlingPanelOKButton && url != nil)
        {
            options = this.exportOptionsView.exportOptions()
            options.destinationURL = url
        }
        else {
            var message = "Kite Export Canceled"

            log(message)
            this.sketchDoc.showMessage(message)
        }

        return options
    },

    tempURLWithFileName: function (fileName) {

        var uuid = NSUUID.UUID().UUIDString()
        var tempURL = Helpers.tempURL().URLByAppendingPathComponent(uuid)

        return tempURL.URLByAppendingPathComponent(fileName)
    },

    moveSavedDocumentAtTempURLToFinalURL: function(tempURL, finalURL) {

        var fileManager = [NSFileManager defaultManager]
        [fileManager removeItemAtURL:finalURL error:null]

        var moveError = null
        var moveWasSuccessful = [fileManager moveItemAtURL:tempURL toURL:finalURL error:moveError]

        if (moveWasSuccessful == false) {
            Helpers.showDialogWithTitleMessage("Saving Document", "An error occurred moving the file to its final destination")
        }
    }
}
